"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createApp = void 0;
const get_fn_context_1 = require("./get-fn-context");
const utils_1 = require("./utils");
function createApp(options) {
    return async function main(params) {
        const fnContext = get_fn_context_1.getFnContext({ dsConfig: options.dsConfig, params });
        try {
            const method = options.handlers[params.methodName];
            if (!method) {
                throw new Error(`method ${params.methodName} not found in datasource, or not enabled in this datasource`);
            }
            let fnParams = params.params || {};
            if (!method.isHttp && utils_1.isObj(params, 'defaultParams')) {
                fnParams = utils_1.mergeDeep(params.defaultParams, params.params || {});
            }
            const result = await method(fnParams, fnContext);
            return {
                code: 0,
                data: result,
            };
        }
        catch (e) {
            if (e instanceof utils_1.TCBError) {
                return {
                    code: e.code || -1,
                    message: e.message,
                };
            }
            return {
                code: -1,
                message: e.message,
            };
        }
    };
}
exports.createApp = createApp;
