"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFnContext = void 0;
/**
 * 获取单个数据源云函数的context
 */
const tcb_1 = require("./tcb");
const utils_1 = require("./utils");
function getFnContext(config) {
    var _a, _b;
    const envObj = tcb_1.tcb.getCloudbaseContext();
    const isPreview = typeof config.isPreview === 'boolean' ? config.isPreview : !!process.env.IS_PREVIEW;
    // @ts-ignore
    const dsFullName = config.dsConfig && utils_1.getDsFullName(config.dsConfig, isPreview);
    // 目前仅内建数据源才有数据库
    const hasDb = ((_a = config.dsConfig) === null || _a === void 0 ? void 0 : _a.type) === 'database';
    const envInfo = {
        openId: envObj.WX_OPENID,
        appId: envObj.WX_APPID,
        uid: envObj.TCB_UUID,
        customUserId: envObj.TCB_CUSTOM_USER_ID || '',
        isAnonymous: envObj.TCB_ISANONYMOUS_USER === 'true',
        dataSourceName: (_b = config.dsConfig) === null || _b === void 0 ? void 0 : _b.name,
        dataSourceFullName: dsFullName,
        isPreview,
        envId: envObj.TCB_ENV,
    };
    // 自定义操作的context
    const cfContext = {
        cloudbase: tcb_1.tcb,
        app: tcb_1.app,
        auth: tcb_1.auth,
        env: envInfo,
        envInfo,
        database: tcb_1.db,
        weixin: getWxCloudInfo(config.params),
        defaultParams: config.params.defaultParams,
        collection: hasDb && dsFullName ? tcb_1.db.collection(dsFullName) : undefined,
    };
    return cfContext;
}
exports.getFnContext = getFnContext;
function getWxCloudInfo(params) {
    const wxReg = /^wx_/;
    const wxKeys = Object.keys(params).filter(k => wxReg.test(k));
    if (!wxKeys.length)
        return null;
    const weixin = {};
    return wxKeys.reduce((acc, cur) => {
        acc[cur.replace(wxReg, '')] = params[cur];
        return acc;
    }, weixin);
}
