"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isObj = exports.mergeDeep = exports.TCBError = exports.getDsFullName = exports.lowercaseKey = exports.capitalizeKey = void 0;
/**
 * 将对象的key的首字母转换为大写, 适应 yunapi 的命名风格
 *  { userName: 'xxx', id: 'xxx' } => { UserName: 'xxx', Id: 'xxxx'}
 */
function capitalizeKey(obj) {
    const result = {};
    return Object.keys(obj).reduce((acc, key) => {
        const capitalized = key.charAt(0).toUpperCase() + key.slice(1);
        acc[capitalized] = obj[key];
        return acc;
    }, result);
}
exports.capitalizeKey = capitalizeKey;
/**
 * 将对象的 key 转换为全小写
 *  for http header usage
 */
function lowercaseKey(obj) {
    const result = {};
    return Object.keys(obj).reduce((acc, cur) => {
        acc[cur.toLowerCase()] = obj[cur];
        return acc;
    }, result);
}
exports.lowercaseKey = lowercaseKey;
/**
 * 获取数据源完整名称, 该名称用于发布后的tcb云函数, 也用于tcb的数据库名称
 * @param ds 数据源关键信息
 * @param isPreview 是否预览
 * @returns 数据源表名
 */
function getDsFullName(ds, isPreview) {
    return `lcap-${ds.id}-${ds.name}${isPreview ? '-preview' : ''}`;
}
exports.getDsFullName = getDsFullName;
/** 预置的错误对象, 可用该对象抛出自定义错误代码及错误信息 */
class TCBError extends Error {
    constructor(code, message) {
        super(message);
        this.code = code;
        this.name = 'TCBError';
    }
}
exports.TCBError = TCBError;
/* eslint-disable no-param-reassign */
function isObject(obj) {
    return obj && typeof obj === 'object';
}
/**
 * Performs a deep merge of `source` into `target`.
 * Mutates `target` only but not its objects and arrays.
 *
 * @author inspired by [jhildenbiddle](https://stackoverflow.com/a/48218209).
 */
function mergeDeep(target, source) {
    if (!isObject(target) || !isObject(source)) {
        return source;
    }
    Object.keys(source).forEach((key) => {
        const targetValue = target[key];
        const sourceValue = source[key];
        if (Array.isArray(targetValue) && Array.isArray(sourceValue)) {
            target[key] = targetValue.concat(sourceValue);
        }
        else if (isObject(targetValue) && isObject(sourceValue)) {
            target[key] = mergeDeep(Object.assign({}, targetValue), sourceValue);
        }
        else {
            target[key] = sourceValue;
        }
    });
    return target;
}
exports.mergeDeep = mergeDeep;
/** 是否为对象(非数组) */
function isObj(obj, key) {
    const target = obj && key ? obj[key] : obj;
    if (!target)
        return false;
    return !Array.isArray(target) && typeof target === 'object';
}
exports.isObj = isObj;
